@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"io/ioutil"
@@ -27,7 +28,7 @@ import (
 )
 
 func Test_collectionsUsageHandler(t *testing.T) {
-	var testData map[string]interface{}
+	var testData map[string]any
 
 	jsonData, err := ioutil.ReadFile("testdata/top.json")
 	if err != nil {
@@ -56,7 +57,7 @@ func Test_collectionsUsageHandler(t *testing.T) {
 	tests := []struct {
 		name    string
 		args    args
-		want    interface{}
+		want    any
 		wantErr error
 	}{
 		{
@@ -71,7 +72,7 @@ func Test_collectionsUsageHandler(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			got, err := CollectionsUsageHandler(tt.args.s, nil)
+			got, err := CollectionsUsageHandler(context.Background(), tt.args.s, nil)
 			if !errors.Is(err, tt.wantErr) {
 				t.Errorf("collectionsUsageHandler() error = %v, wantErr %v", err, tt.wantErr)
 
