@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -28,7 +29,7 @@ import (
 )
 
 func Test_connPoolStatsHandler(t *testing.T) {
-	var testData map[string]interface{}
+	var testData map[string]any
 
 	jsonData, err := ioutil.ReadFile("testdata/connPoolStats.json")
 	if err != nil {
@@ -60,7 +61,7 @@ func Test_connPoolStatsHandler(t *testing.T) {
 	tests := []struct {
 		name    string
 		args    args
-		want    interface{}
+		want    any
 		wantErr error
 	}{
 		{
@@ -74,7 +75,7 @@ func Test_connPoolStatsHandler(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			got, err := ConnPoolStatsHandler(tt.args.s, tt.args.params)
+			got, err := ConnPoolStatsHandler(context.Background(), tt.args.s, tt.args.params)
 			if !errors.Is(err, tt.wantErr) {
 				t.Errorf("connPoolStatsHandler() error = %v, wantErr %v", err, tt.wantErr)
 
