@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 
 	"go.mongodb.org/mongo-driver/bson"
@@ -23,12 +24,12 @@ import (
 
 // DatabaseStatsHandler
 // https://docs.mongodb.com/manual/reference/command/dbStats/index.html
-func DatabaseStatsHandler(s Session, params map[string]string) (interface{}, error) {
+func DatabaseStatsHandler(ctx context.Context, s Session, params map[string]string) (any, error) {
 	dbStats := &bson.M{}
 	err := s.DB(params["Database"]).Run(
+		ctx,
 		&bson.D{
 			{Key: "dbStats", Value: 1},
-			{Key: "maxTimeMS", Value: s.GetMaxTimeMS()},
 		},
 		dbStats,
 	)
