@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"io/ioutil"
@@ -28,7 +29,7 @@ import (
 )
 
 func Test_databaseStatsHandler(t *testing.T) {
-	var testData map[string]interface{}
+	var testData map[string]any
 
 	jsonData, err := ioutil.ReadFile("testdata/dbStats.json")
 	if err != nil {
@@ -58,7 +59,7 @@ func Test_databaseStatsHandler(t *testing.T) {
 	tests := []struct {
 		name    string
 		args    args
-		want    interface{}
+		want    any
 		wantErr error
 	}{
 		{
@@ -92,7 +93,7 @@ func Test_databaseStatsHandler(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			got, err := DatabaseStatsHandler(tt.args.s, tt.args.params)
+			got, err := DatabaseStatsHandler(context.Background(), tt.args.s, tt.args.params)
 			if !errors.Is(err, tt.wantErr) {
 				t.Errorf("databaseStatsHandler() error = %v, wantErr %v", err, tt.wantErr)
 
