@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 	"sort"
 
@@ -27,8 +28,8 @@ type dbEntity struct {
 
 // DatabasesDiscoveryHandler
 // https://docs.mongodb.com/manual/reference/command/listDatabases/
-func DatabasesDiscoveryHandler(s Session, _ map[string]string) (interface{}, error) {
-	dbs, err := s.DatabaseNames()
+func DatabasesDiscoveryHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
+	dbs, err := s.DatabaseNames(ctx)
 	if err != nil {
 		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
 	}
