@@ -15,19 +15,21 @@
 package handlers
 
 import (
+	"context"
+
 	"go.mongodb.org/mongo-driver/bson"
 	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // JumboChunksHandler
 // https://docs.mongodb.com/manual/core/sharding-data-partitioning/#indivisible-jumbo-chunks
-func JumboChunksHandler(s Session, _ map[string]string) (interface{}, error) {
-	q, err := s.DB("config").C("chunks").Find(bson.M{"jumbo": true})
+func JumboChunksHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
+	q, err := s.DB("config").C("chunks").Find(ctx, bson.M{"jumbo": true})
 	if err != nil {
 		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
 	}
 
-	jumboChunks, err := q.Count()
+	jumboChunks, err := q.Count(ctx)
 	if err != nil {
 		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
 	}
