@@ -14,10 +14,12 @@
 
 package handlers
 
+import "context"
+
 // PingHandler executes 'ping' command and returns pingOk if a connection is alive or pingFailed otherwise.
 // https://docs.mongodb.com/manual/reference/command/ping/index.html
-func PingHandler(s Session, _ map[string]string) (interface{}, error) {
-	if err := s.Ping(); err != nil {
+func PingHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
+	if err := s.Ping(ctx); err != nil {
 		Logger.Debugf("ping failed, %s", err.Error())
 
 		return PingFailed, nil
