@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"strings"
@@ -37,24 +38,23 @@ type Member struct {
 	optime int
 	state  int
 	name   string
-	ptr    interface{}
+	ptr    any
 }
 
-type rawMember = map[string]interface{}
+type rawMember = map[string]any
 
 var errUnknownStructure = errors.New("failed to parse the members structure")
 
-func parseMembers(raw []interface{}) (result []Member, err error) {
+func parseMembers(raw []any) ([]Member, error) {
 	var (
 		members     []Member
 		primaryNode Member
 	)
 
 	for _, m := range raw {
-		var member Member
-		member, err = paseMember(m)
+		member, err := parseMember(m)
 		if err != nil {
-			return
+			return nil, err
 		}
 
 		if member.state == statePrimary {
@@ -64,7 +64,7 @@ func parseMembers(raw []interface{}) (result []Member, err error) {
 		}
 	}
 
-	result = append([]Member{primaryNode}, members...)
+	result := append([]Member{primaryNode}, members...)
 	if len(result) == 0 {
 		return nil, errUnknownStructure
 	}
@@ -72,39 +72,47 @@ func parseMembers(raw []interface{}) (result []Member, err error) {
 	return result, nil
 }
 
-func paseMember(m interface{}) (member Member, err error) {
-	ok := true
+func parseMember(m any) (Member, error) {
+	var (
+		member       Member
+		extractedNum int
+	)
 
 	if v, ok := m.(rawMember)["name"].(string); ok {
 		member.name = v
+		extractedNum++
 	}
 
 	if v, ok := m.(rawMember)["health"].(float64); ok {
 		member.health = int(v)
+		extractedNum++
 	}
 
-	if v, ok := m.(rawMember)["optime"].(map[string]interface{}); ok {
-		if pa, ok := v["ts"].(primitive.Timestamp); ok {
+	if v, ok := m.(rawMember)["optime"].(map[string]any); ok {
+		if pa, tsOk := v["ts"].(primitive.Timestamp); tsOk {
 			member.optime = int(time.Unix(int64(pa.T), 0).Unix())
 		} else {
 			member.optime = int(int64(v["ts"].(float64)))
 		}
+
+		extractedNum++
 	}
 
 	if v, ok := m.(rawMember)["state"].(int32); ok {
 		member.state = int(v)
+		extractedNum++
 	}
 
-	if !ok {
+	if extractedNum == 0 {
 		return member, errUnknownStructure
 	}
 
 	member.ptr = m
 
-	return
+	return member, nil
 }
 
-func injectExtendedMembersStats(raw []interface{}) error {
+func injectExtendedMembersStats(raw []any) error {
 	members, err := parseMembers(raw)
 	if err != nil {
 		return err
@@ -138,19 +146,16 @@ func injectExtendedMembersStats(raw []interface{}) error {
 
 // ReplSetStatusHandler
 // https://docs.mongodb.com/manual/reference/command/replSetGetStatus/index.html
-func ReplSetStatusHandler(s Session, _ map[string]string) (interface{}, error) {
-	var replSetGetStatus map[string]interface{}
+func ReplSetStatusHandler(ctx context.Context, s Session, _ map[string]string) (any, error) {
+	var replSetGetStatus map[string]any
 
 	err := s.DB("admin").Run(
+		ctx,
 		&bson.D{
 			{
 				Key:   "replSetGetStatus",
 				Value: 1,
 			},
-			{
-				Key:   "maxTimeMS",
-				Value: s.GetMaxTimeMS(),
-			},
 		},
 		&replSetGetStatus,
 	)
@@ -165,7 +170,9 @@ func ReplSetStatusHandler(s Session, _ map[string]string) (interface{}, error) {
 
 	if pa, ok := replSetGetStatus["members"].(primitive.A); ok {
 		Logger.Debugf("members got as primitive A")
-		i := []interface{}(pa)
+
+		i := []any(pa)
+
 		Logger.Debugf("value:%v\n type: %T\n", i, i)
 
 		err = injectExtendedMembersStats(i)
