@@ -15,6 +15,7 @@
 package handlers
 
 import (
+	"context"
 	"errors"
 
 	"go.mongodb.org/mongo-driver/mongo/options"
@@ -42,24 +43,23 @@ var errNotFound = errors.New("not found")
 // Session is an interface to access to the session struct.
 type Session interface {
 	DB(name string) Database
-	DatabaseNames() (names []string, err error)
-	GetMaxTimeMS() int64
-	Ping() error
+	DatabaseNames(ctx context.Context) (names []string, err error)
+	Ping(ctx context.Context) error
 }
 
 type Database interface {
 	C(name string) Collection
-	CollectionNames() (names []string, err error)
-	Run(cmd, result interface{}) error
+	CollectionNames(ctx context.Context) (names []string, err error)
+	Run(ctx context.Context, cmd, result any) error
 }
 
 type Collection interface {
-	Find(query interface{}, opts ...*options.FindOptions) (q Query, err error)
-	FindOne(query interface{}, opts ...*options.FindOneOptions) Query
+	Find(ctx context.Context, query any, opts ...*options.FindOptions) (q Query, err error)
+	FindOne(ctx context.Context, query any, opts ...*options.FindOneOptions) Query
 }
 
 type Query interface {
-	Count() (n int, err error)
-	Get(result interface{}) error
-	GetSingle(result interface{}) error
+	Count(ctx context.Context) (n int, err error)
+	Get(ctx context.Context, result any) error
+	GetSingle(result any) error
 }
