@@ -15,9 +15,12 @@
 package plugin
 
 import (
+	"context"
+	"errors"
 	"time"
 
 	"golang.zabbix.com/plugin/mongodb/plugin/handlers"
+	"golang.zabbix.com/sdk/errs"
 	"golang.zabbix.com/sdk/metric"
 	"golang.zabbix.com/sdk/plugin"
 	"golang.zabbix.com/sdk/uri"
@@ -38,7 +41,10 @@ type Plugin struct {
 	options PluginOptions
 }
 
-func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvider) (result interface{}, err error) {
+// Export metrics.
+//
+//nolint:gocyclo,cyclop
+func (p *Plugin) Export(key string, rawParams []string, pluginCtx plugin.ContextProvider) (any, error) {
 	params, _, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
 	if err != nil {
 		return nil, err
@@ -76,9 +82,26 @@ func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvid
 
 	p.Debugf("Params: %v", params)
 
-	result, err = handleMetric(conn, params)
+	timeout := conn.getTimeout()
+
+	if timeout < time.Second*time.Duration(pluginCtx.Timeout()) {
+		timeout = time.Second * time.Duration(pluginCtx.Timeout())
+	}
+
+	ctx, cancel := context.WithTimeout(context.Background(), timeout)
+	defer cancel()
+
+	result, err := handleMetric(ctx, conn, params)
 	if err != nil {
 		p.Errf(err.Error())
+
+		ctxErr := ctx.Err()
+
+		if ctxErr != nil && errors.Is(ctxErr, context.DeadlineExceeded) {
+			return nil, errs.New("request execution timeout exceeded")
+		}
+
+		return nil, errs.Wrap(err, "failed to run command")
 	}
 
 	return result, err
